This is unreleased documentation for the main (development) branch of crypto-glue.

Validity

Struct Validity 

pub struct Validity<P: Profile = Rfc5280> {
    pub not_before: Time,
    pub not_after: Time,
    /* private fields */
}
X.501 Validity as defined in RFC 5280 Section 4.1.2.5

Validity ::= SEQUENCE {
    notBefore      Time,
    notAfter       Time
}

Fields

not_before: Time

notBefore value

not_after: Time

notAfter value

Implementations

Source

impl<P> Validity<P>
where P: Profile,

pub const fn new(not_before: Time, not_after: Time) -> Self

Creates a Validity with the provided bounds

pub fn from_now(duration: Duration) -> Result<Self>

Creates a Validity which starts now and lasts for duration.

pub fn infinity() -> Result<Self>

Creates a Validity which starts now and does not expire.